==> haskell-vector-binary-instances-0.2.3.5-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-binary-instances
version: 0.2.3.5
id: vector-binary-instances-0.2.3.5-Do2uVjLEGQcAMYmorIf1G3
key: vector-binary-instances-0.2.3.5-Do2uVjLEGQcAMYmorIf1G3
license: BSD3
maintainer: dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>
stability: Experimental
homepage: https://github.com/bos/vector-binary-instances
synopsis: Instances of Data.Binary and Data.Serialize for vector
description:
    Instances for Binary for the types defined in the vector package,
    making it easy to serialize vectors to and from disk. We use the
    generic interface to vectors, so all vector types are supported.
    Specific instances are provided for unboxed, boxed and storable
    vectors.
    .
    To serialize a vector:
    .
    > *Data.Vector.Binary> let v = Data.Vector.fromList [1..10]
    > *Data.Vector.Binary> v
    > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
    > *Data.Vector.Binary> encode v
    > Chunk "\NUL\NUL\NUL\NUL\NUL...\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\n" Empty
    .
    Which you can in turn compress before writing to disk:
    .
    > compress . encode $ v
    > Chunk "\US\139\b\NUL\NUL\N...\229\240,\254:\NUL\NUL\NUL" Empty
category: Data
author: Don Stewart
exposed: True
exposed-modules:
    Data.Vector.Binary
abi: ea88d81f4c0f7618585ac61ff7e36a3f
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/vector-binary-instances-0.2.3.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/vector-binary-instances-0.2.3.5
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/vector-binary-instances-0.2.3.5
hs-libraries: HSvector-binary-instances-0.2.3.5-Do2uVjLEGQcAMYmorIf1G3
depends:
    base-4.9.1.0 binary-0.8.3.0 vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-binary-instances-0.2.3.5-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-binary-instances
version: 0.2.3.5
id: vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD
key: vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD
license: BSD3
maintainer: dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>
stability: Experimental
homepage: https://github.com/bos/vector-binary-instances
synopsis: Instances of Data.Binary and Data.Serialize for vector
description:
    Instances for Binary for the types defined in the vector package,
    making it easy to serialize vectors to and from disk. We use the
    generic interface to vectors, so all vector types are supported.
    Specific instances are provided for unboxed, boxed and storable
    vectors.
    .
    To serialize a vector:
    .
    > *Data.Vector.Binary> let v = Data.Vector.fromList [1..10]
    > *Data.Vector.Binary> v
    > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
    > *Data.Vector.Binary> encode v
    > Chunk "\NUL\NUL\NUL\NUL\NUL...\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\n" Empty
    .
    Which you can in turn compress before writing to disk:
    .
    > compress . encode $ v
    > Chunk "\US\139\b\NUL\NUL\N...\229\240,\254:\NUL\NUL\NUL" Empty
category: Data
author: Don Stewart
exposed: True
indefinite: False
exposed-modules:
    Data.Vector.Binary
abi: b1e020dd6984c8831af2f8a0a4fee437
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/vector-binary-instances-0.2.3.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/vector-binary-instances-0.2.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/vector-binary-instances-0.2.3.5
hs-libraries: HSvector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD
depends:
    base-4.10.0.0 vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi binary-0.8.5.1
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=12d01284f86dd305f0b2cab827808cc2
             binary-0.8.5.1=230c80b11ae3b1af831989b945ccdad4
haddock-interfaces: /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
